Exceptions
**********

.. autoapiexception:: pikepdf.exceptions.PdfError

.. autoapiexception:: pikepdf.exceptions.PasswordError

.. autoapiexception:: pikepdf.exceptions.ForeignObjectError

.. autoapiexception:: pikepdf.exceptions.OutlineStructureError

.. autoapiexception:: pikepdf.exceptions.UnsupportedImageTypeError

.. autoapiexception:: pikepdf.exceptions.HifiPrintImageNotTranscodableError

.. autoapiexception:: pikepdf.exceptions.InvalidPdfImageError

.. autoapiexception:: pikepdf.exceptions.DataDecodingError

.. autoapiexception:: pikepdf.exceptions.DeletedObjectError

.. autoapiexception:: pikepdf.exceptions.DependencyError

.. autoapiexception:: pikepdf.exceptions.PdfParsingError

.. autoapiexception:: pikepdf.exceptions.JobUsageError

.. autoapiexception:: pikepdf.exceptions.ImageDecompressionError